@@ -39,13 +39,9 @@ typedef struct
     char       *m_stderrPath;
     char       *m_cwdPath;
     int         m_fdReceived;
-    char        m_bwrap;
-    char        m_cgroup;
-
 } lscgid_t;
 
 
-extern int applyLimits(lscgid_t *pCGI);
 
 #ifdef __cplusplus
 }
