@@ -60,8 +60,8 @@ const char *HttpHeader::s_pHeaderNames[H_HEADER_END + 1] =
     "If-Modified-Since",
     "If-Match",
     "If-None-Match",
-    "If-Range",
     "If-Unmodified-Since",
+    "If-Range",
     "Keep-Alive",
     "Range",
     "Transfer-Encoding",
@@ -285,7 +285,7 @@ size_t HttpHeader::getIndex2(const char *pHeader)
     if (idx < H_HEADER_END)
     {
         char ch = *(pHeader + getHeaderStringLen(idx));
-        if ((!ch) || (ch == ' ') || (ch == '\t'))
+        if (!ch || ch == ' ' || ch == '\t' || ch == ':')
             return idx;
     }
     return H_HEADER_END;
