@@ -19,8 +19,8 @@
 #define DATETIME_H
 
 
-
 #include <time.h>
+#include <lsr/ls_atomic.h>
 
 #define RFC_1123_TIME_LEN 29
 class DateTime
@@ -35,6 +35,11 @@ public:
     static char  *getRFCTime(time_t t, char *buf);
     static char  *getLogTime(time_t lTime, char *pBuf, int bGMT = 0);
 
+    static inline time_t getCurTime()
+    {   return ls_atomic_value(&s_curTime);      }
+    static inline int getCurTimeUs()
+    {   return ls_atomic_value(&s_curTimeUs);     }
+
 };
 
 #endif
